@@ -21,5 +21,6 @@ urlpatterns = [
         "docs/", schema_view.with_ui("redoc", cache_timeout=0), name="schema-swagger-ui"
     ),
     path("admin/", admin.site.urls),
-    path("store/", include("ob_dj_store.apis.stores.urls")),
+    path("ecom/", include("ob_dj_store.apis.stores.urls")),
+    path("tap/", include("ob_dj_store.apis.tap.urls")),
 ]
