@@ -51,7 +51,7 @@ class OpeningHoursAdmin(admin.ModelAdmin):
 
 
 class CategoryAdmin(admin.ModelAdmin):
-    list_display = ["name"]
+    list_display = ["name", "description", "parent"]
 
 
 class AttributeChoiceInlineAdmin(admin.TabularInline):
@@ -72,17 +72,15 @@ class ProductVariantAdmin(admin.ModelAdmin):
     list_display = [
         "name",
         "product",
-        "price",
-        "quantity",
         "has_inventory",
-        "is_deliverable",
-        "is_active",
-        "preparation_time",
     ]
 
 
 class ProductAdmin(admin.ModelAdmin):
-    list_display = ["id", "name", "store"]
+    list_display = [
+        "id",
+        "name",
+    ]
     inlines = [ProductVariantInlineAdmin, ProductMediaInlineAdmin]
 
 
@@ -163,6 +161,13 @@ class FeedbackConfigAdmin(admin.ModelAdmin):
     ]
 
 
+class PhoneContactAdmin(admin.ModelAdmin):
+    list_display = [
+        "phone_number",
+        "store",
+    ]
+
+
 admin.site.register(models.Store, StoreAdmin)
 admin.site.register(models.OpeningHours, OpeningHoursAdmin)
 admin.site.register(models.ShippingMethod, ShippingMethodAdmin)
@@ -178,3 +183,4 @@ admin.site.register(models.Feedback, FeedbackAdmin)
 admin.site.register(models.FeedbackAttribute, FeedbackAttributeAdmin)
 admin.site.register(models.FeedbackConfig, FeedbackConfigAdmin)
 admin.site.register(models.AttributeChoice, AttributeChoiceAdmin)
+admin.site.register(models.PhoneContact, PhoneContactAdmin)
