@@ -21,6 +21,7 @@ from ob_dj_store.core.stores.models._product import (
 from ob_dj_store.core.stores.models._store import (
     OpeningHours,
     PaymentMethod,
+    PhoneContact,
     ShippingMethod,
     Store,
 )
@@ -50,4 +51,5 @@ __all__ = [
     "Feedback",
     "FeedbackAttribute",
     "FeedbackConfig",
+    "PhoneContact",
 ]
