@@ -1,6 +1,7 @@
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
@@ -42,6 +43,9 @@ class CartItem(models.Model):
         "stores.ProductVariant", on_delete=models.CASCADE
     )
     quantity = models.PositiveIntegerField(default=1)
+    store = models.ForeignKey(
+        "stores.Store", on_delete=models.CASCADE, related_name="store_items"
+    )
     # notes for special instructions, can be empty
     notes = models.TextField(blank=True, null=True, help_text=_("Special instructions"))
     # attribute choices for the item
@@ -63,7 +67,19 @@ class CartItem(models.Model):
 
     @property
     def unit_price(self) -> Decimal:
-        return self.product_variant.price
+        try:
+            return self.product_variant.inventories.get(
+                store=self.store
+            ).discounted_price
+        except ObjectDoesNotExist:
+            return 0
+
+    @property
+    def inventory(self) -> Decimal:
+        try:
+            return self.product_variant.inventories.get(store=self.store)
+        except ObjectDoesNotExist:
+            return None
 
     @property
     def total_price(self) -> Decimal:
