@@ -1,6 +1,7 @@
 from decimal import Decimal
 
 from django.contrib.auth import get_user_model
+from django.core.exceptions import ObjectDoesNotExist
 from django.core.validators import MinValueValidator
 from django.db import models
 from django.utils.translation import gettext_lazy as _
@@ -36,16 +37,28 @@ class Order(DjangoModelCleanMixin, models.Model):
         "stores.Store", related_name="orders", on_delete=models.CASCADE
     )
     shipping_method = models.ForeignKey(
-        "stores.ShippingMethod", related_name="orders", on_delete=models.CASCADE
+        "stores.ShippingMethod",
+        related_name="orders",
+        on_delete=models.CASCADE,
+        null=True,
+        blank=True,
     )
     payment_method = models.ForeignKey(
-        "stores.PaymentMethod", related_name="orders", on_delete=models.CASCADE
+        "stores.PaymentMethod",
+        related_name="orders",
+        on_delete=models.CASCADE,
+        null=True,
+        blank=True,
     )
     shipping_address = models.ForeignKey(
-        "stores.address", on_delete=models.PROTECT, related_name="orders"
+        "stores.address",
+        on_delete=models.PROTECT,
+        related_name="orders",
     )
     immutable_shipping_address = models.ForeignKey(
-        "stores.ImmutableAddress", on_delete=models.PROTECT, related_name="orders"
+        "stores.ImmutableAddress",
+        on_delete=models.PROTECT,
+        related_name="orders",
     )
     status = models.CharField(
         max_length=32,
@@ -101,7 +114,7 @@ class Order(DjangoModelCleanMixin, models.Model):
         return sum(map(lambda item: item.preparation_time, self.items.all()))
 
     def save(self, **kwargs):
-        if not self.pk:
+        if not self.pk and self.shipping_address:
             self.immutable_shipping_address = self.shipping_address.to_immutable()
         return super().save(**kwargs)
 
@@ -140,7 +153,7 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
     )
 
     def __str__(self):
-        return f"OrderItem - {self.quantity} {self.variant.name}"
+        return f"OrderItem - {self.quantity} {self.product_variant.name}"
 
     class Meta:
         verbose_name = _("Order Item")
@@ -148,14 +161,30 @@ class OrderItem(DjangoModelCleanMixin, models.Model):
 
     @property
     def total_amount(self):
-        return self.product_variant.price * self.quantity
+        try:
+            return (
+                self.product_variant.inventories.get(store=self.order.store).price
+                * self.quantity
+            )
+        except ObjectDoesNotExist:
+            return 0
 
     @property
     def preparation_time(self):
         return (
-            self.product_variant.preparation_time.total_seconds() * self.quantity
+            self.product_variant.inventories.get(
+                store=self.order.store
+            ).preparation_time.total_seconds()
+            * self.quantity
         ) / 60
 
+    @property
+    def inventory(self) -> Decimal:
+        try:
+            return self.product_variant.inventories.get(store=self.order.store)
+        except ObjectDoesNotExist:
+            return None
+
 
 class OrderHistory(DjangoModelCleanMixin, models.Model):
     """
