@@ -4,6 +4,7 @@ from django.conf import settings
 from django.contrib.gis.db import models
 from django.core.exceptions import ValidationError
 from django.utils.translation import gettext_lazy as _
+from phonenumber_field.modelfields import PhoneNumberField
 
 from ob_dj_store.core.stores.managers import (
     PaymentMethodManager,
@@ -159,6 +160,9 @@ class OpeningHours(DjangoModelCleanMixin, models.Model):
     store = models.ForeignKey(
         Store, on_delete=models.CASCADE, related_name="opening_hours"
     )
+    # Audit fields
+    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(auto_now=True)
 
     class Meta:
         ordering = ("weekday", "from_hour")
@@ -176,3 +180,27 @@ class OpeningHours(DjangoModelCleanMixin, models.Model):
             raise ValidationError(
                 _("From hour should be lower than To hour"), code="invalid"
             )
+
+
+class PhoneContact(DjangoModelCleanMixin, models.Model):
+    """
+    PhoneContact model linked to store model
+    every store has many phone_contacts
+    """
+
+    phone_number = PhoneNumberField(unique=True)
+    store = models.ForeignKey(
+        "Store", on_delete=models.CASCADE, related_name="phone_contacts"
+    )
+    is_default = models.BooleanField(default=False)
+    is_active = models.BooleanField(default=True)
+    # Audit fields
+    created_at = models.DateTimeField(auto_now_add=True)
+    updated_at = models.DateTimeField(auto_now=True)
+
+    class Meta:
+        verbose_name_plural = _("PhoneContacts")
+        verbose_name = _("PhoneContact")
+
+    def __str__(self) -> str:
+        return f"Phone Contacts for store {self.store}"
